@@ -3,7 +3,11 @@ macro_rules! r#kern_try {
     ($expr:expr) => {
         match $expr {
             mach::kern_return::KERN_SUCCESS => (),
-            err_code => return ::std::result::Result::Err(::std::io::Error::from_raw_os_error(err_code).into()),
+            err_code => {
+                return ::std::result::Result::Err(
+                    ::std::io::Error::from_raw_os_error(err_code).into(),
+                )
+            }
         }
     };
     ($expr:expr,) => {
